@@ -58,14 +58,15 @@ def init(args):
             return
         io = NWBHDF5IO(args[0], 'r')
         nwbfile_in = io.read()
-
-        print(nwbfile_in.get_scratch('nwborglab_sensors'))
+                
         sensors_sapofto = SAPOFTO.SAPOFTO('sensors',nwbfile_in.get_scratch('nwborglab_sensors'), case_sensitive=True)
         overview_sapofto = SAPOFTO.SAPOFTO('OVERVIEW',nwbfile_in.get_scratch('nwborglab_overview'))
         session_skeleton_sapofto = SAPOFTO.SAPOFTO('SKELETONS',nwbfile_in.get_scratch('nwborglab_session_skeleton'))
         #session_skeleton_sapofto = nwbfile_in.get_scratch('nwborglab_session_source_code')
         
         SAPOFTO.recursiveFolderWrite(sensors_sapofto, os.getcwd(), safe_mode=True)
+        SAPOFTO.recursiveFolderWrite(overview_sapofto, os.getcwd(), safe_mode=True)
+        SAPOFTO.recursiveFolderWrite(session_skeleton_sapofto, os.getcwd(), safe_mode=True)
         return
     
     tab = '    '
